@@ -81,10 +81,12 @@ Returns a string with a locally unique name of the device
 Returns a string with a locally unique name of the parent
 of the device, or undef if there is no parent
 
-=item my $xml = $dev->get_xml_description()
+=item my $xml = $dev->get_xml_description($flags=0)
 
-Returns an XML document containing a complete description of
-the storage dev's configuration
+Returns an XML document containing a complete description of the node
+device's configuration. The optional $flags parameter controls
+generation of the XML document, defaulting to 0 if omitted. It can be
+one or more of the XML DUMP constants listed later in this document.
 
 =item $dev->reattach()
 
@@ -139,6 +141,13 @@ with it.
 
 Return a list of all capabilities in the device.
 
+=item $dev->update($xml, $flags=0)
+
+Update the definition of an existing node device with C<$xml>. The
+C<$flags> parameter can be use to control which config is affected
+(see XML UPDATE FLAGS) and defaults to zero (affect current state of
+the node device).
+
 =back
 
 =head1 CONSTANTS
@@ -248,6 +257,14 @@ Include active devices
 
 Include inactive devices
 
+=item Sys::Virt::NodeDevice::LIST_PERSISTENT
+
+Include persistent devices
+
+=item Sys::Virt::NodeDevice::LIST_TRANSIENT
+
+Include transient devices
+
 =back
 
 =head2 EVENT ID CONSTANTS
@@ -310,6 +327,37 @@ Validate the XML document against schema
 
 =back
 
+=head2 NODE DEVICE UPDATE
+
+=over 4
+
+=item Sys::Virt::NodeDevice::UPDATE_AFFECT_CURRENT
+
+Affect live if node device is active, config if it's not active
+
+=item Sys::Virt::NodeDevice::UPDATE_AFFECT_LIVE
+
+Affect live state of node device only
+
+=item Sys::Virt::NodeDevice::UPDATE_AFFECT_CONFIG
+
+Affect persistent config only
+
+=back
+
+=head2 XML DUMP OPTIONS
+
+The following constants are used to control the information
+included in the XML configuration dump
+
+=over 4
+
+=item Sys::Virt::NodeDevice::XML_INACTIVE
+
+Report the persistent inactive configuration for the node device.
+
+=back
+
 =cut
 
 
